@@ -78,7 +78,8 @@ def get_distro_name():
        name = os.popen('lsb_release -i | cut -f 2')
        os_name = name.read().strip()
        name.close()
-    else:
+
+    if not os_name:
        name = os.popen("cat /etc/issue 2>/dev/null | awk '{print $1}' | head -n 1")
        os_name = name.read().strip()
        name.close()
@@ -181,7 +182,7 @@ class Password(object):
         ok, ret = False, ''
 
         try:
-            child = pexpect.spawn(cmd, timeout=1)
+            child = pexpect.spawn(cmd, timeout=timeout)
         except pexpect.ExceptionPexpect:
             return 1, ''
 
@@ -198,7 +199,7 @@ class Password(object):
                         # output
                         start = time.time()
                         log.log_to_file(cb)
-                        log.debug(cb)
+                        #log.debug(cb)
                         output.write(cb)
 
                     if i == 0: # EOF
