@@ -20,81 +20,24 @@
 # Author: Amarnath Chitumalla
 #
 
-__version__ = '1.1'
-__title__ = 'HP device setup using USB'
+__version__ = '1.2'
+__title__ = 'HP device config using USB'
 __mod__ = 'hp-config_usb_printer'
-__doc__ = "Udev invokes this tool. Tool configures the USB connected devices (if not configured), detects the plugin, queues issues and notifies to logged-in user."
+__doc__ = "Udev invokes this tool. Tool detects the plugin, Smart Install (C/DVD-ROM) issues and notifies to logged-in user. Tool also downloads firmware to the device."
 
 # Std Lib
 import sys
 import os
-import getopt
-import commands
-import re
-import time
 
 # Local
 from base.g import *
-from base import device,utils, tui, models,module, services, os_utils
-from prnt import cups
+from base import device, utils, module, services
 from installer import pluginhandler
 
-LPSTAT_PAT = re.compile(r"""(\S*): (.*)""", re.IGNORECASE)
-USB_PATTERN = re.compile(r'''serial=(.*)''',re.IGNORECASE)
-BACK_END_PATTERN = re.compile(r'''(.*):(.*)''',re.IGNORECASE)
-USB_SERIAL_INTERFACE = re.compile(r'''(.*)&interface.*''',re.IGNORECASE)
-DBUS_SERVICE='com.hplip.StatusService'
-DBUS_AVIALABLE=False
+DBUS_SERVICE = 'com.hplip.StatusService'
+DBUS_AVIALABLE = False
 
 ##### METHODS #####
-
-# remove queues using cups API
-def remove_queues(arg_queues_list):
-    for queue_name in arg_queues_list:
-        cups.delPrinter(queue_name)
-
-
-#Function:  get_queues
-#       Returns the HP, Non HP configured queuese list for a given device serial No and backend
-def get_queues(arg_serial_no, arg_back_end):
-    status, output = utils.run('lpstat -v')
-    hp_conf_queues = []
-    non_hp_conf_queues = []
-    for p in output.splitlines():
-        try:
-            match = LPSTAT_PAT.search(p)
-            printer_name = match.group(1)
-            device_uri = match.group(2)
-            if device_uri.startswith("cups-pdf:/") or not USB_PATTERN.search(device_uri):
-                continue
-
-            back_end = BACK_END_PATTERN.search(device_uri).group(1)
-            serial = USB_PATTERN.search(device_uri).group(1)
-            if USB_SERIAL_INTERFACE.search(serial):
-                serial = USB_SERIAL_INTERFACE.search(serial).group(1)
-
-            log.debug("arg_serial_no[%s] serial[%s] arg_back_end[%s] back_end[%s]"%(arg_serial_no, serial, arg_back_end, back_end))
-            if arg_serial_no == serial and (arg_back_end == back_end or back_end == 'usb'):
-                if printer_name.find('_') == -1 and printer_name.find('-') != -1:
-                    non_hp_conf_queues.append(printer_name)
-                else:
-                    hp_conf_queues.append(printer_name)
-
-        except AttributeError:
-            pass
-
-    log.debug( "serial No [%s] HP Configured Queues [%s] Non HP Configured Queues [%s]"%(arg_serial_no, hp_conf_queues,non_hp_conf_queues))
-    return hp_conf_queues, non_hp_conf_queues
-
-
-def check_cups_process():
-    cups_running_sts = False
-    sts, output = utils.run('lpstat -r')
-    if sts == 0 and ('is running' in output):
-        cups_running_sts = True
-
-    return cups_running_sts
-
 # Send dbus event to hpssd on dbus system bus
 def send_message(device_uri, printer_name, event_code, username, job_id, title, pipe_name=''):
     if DBUS_AVIALABLE == False:
@@ -138,17 +81,15 @@ def start_systray():
 
 
 USAGE = [ (__doc__, "", "name", True),
-          ("Usage: %s [OPTIONS] [SERIAL NO.|USB bus:device]" % __mod__, "", "summary", True),
+          ("Usage: %s [OPTIONS] [USB bus:device]" % __mod__, "", "summary", True),
           utils.USAGE_OPTIONS,
           utils.USAGE_LOGGING1, utils.USAGE_LOGGING2, utils.USAGE_LOGGING3,
           utils.USAGE_HELP,
-          ("[SERIAL NO.|USB bus:device]", "", "heading", False),
+          ("[USB bus:device]", "", "heading", False),
           ("USB bus:device :", """"xxx:yyy" where 'xxx' is the USB bus and 'yyy' is the USB device. (Note: The ':' and all leading zeros must be present.)""", 'option', False),
           ("", "Use the 'lsusb' command to obtain this information.", "option", False),
-          ("SERIAL NO.:", '"serial no." (future use)', "option", True),
           utils.USAGE_EXAMPLES,
           ("USB, IDs specified:", "$%s 001:002"%(__mod__), "example", False),
-          ("USB, using serial number:", "$%s US12345678A"%(__mod__), "example", False),
           utils.USAGE_SPACE,
           utils.USAGE_NOTES,
           ("1. Using 'lsusb' to obtain USB IDs: (example)", "", 'note', False),
@@ -201,8 +142,6 @@ try:
 
     # ******************************* QUERY MODEL AND CHECKING SUPPORT
     log.debug("\nSetting up device: %s\n" % device_uri)
-    back_end, is_hp, bus, model, serial, dev_file, host, zc, port = device.parseDeviceURI(device_uri)
-
     mq = device.queryModelByURI(device_uri)
     if not mq or mq.get('support-type', SUPPORT_TYPE_NONE) == SUPPORT_TYPE_NONE:
         log.error("Unsupported printer model.")
@@ -211,31 +150,13 @@ try:
     printer_name = ""
     username = prop.username
     job_id = 0
-    # ******************************* STARTING CUPS SERVICE, IF NOT RUNNING.
-    while check_cups_process() is False:
-        log.debug("CUPS is not running.. waiting for 30 sec")
-        time.sleep(30)
-
-    # ******************************* RUNNING HP-SETUP, IF QUEUE IS NOT ADDED
-    time.sleep(1)
-    norm_model = models.normalizeModelName(model).lower()
-    if not mq.get('fax-type', FAX_TYPE_NONE) in (FAX_TYPE_NONE, FAX_TYPE_NOT_SUPPORTED):
-        fax_queues_list, fax_config_list_non_hp_conf = get_queues(serial, 'hpfax')
-        remove_queues(fax_config_list_non_hp_conf)
-
-    print_queues_list, print_queues_list_non_hp_conf = get_queues(serial, back_end)
-    remove_queues(print_queues_list_non_hp_conf)     # Removing Queues which are not configured by HPLIP
-    if len(print_queues_list) ==0:
-        if "SMART_INSTALL_ENABLED" not in device_uri:
-            cmd ="hp-setup -i -x -a -q %s"%param
-            log.debug("%s"%cmd)
-            os_utils.execute(cmd)
 
+    # ******************************* Detecting smart install /CD-DVD ROM enable.
+    if "SMART_INSTALL_ENABLED" in device_uri:
         if start_systray():
-            if "SMART_INSTALL_ENABLED" in device_uri:
-                send_message( device_uri, printer_name, EVENT_DIAGNOSE_PRINTQUEUE, username, job_id,'')
-            else:
-                send_message( device_uri, printer_name, EVENT_ADD_PRINTQUEUE, username, job_id,'')
+            send_message( device_uri, printer_name, EVENT_DIAGNOSE_PRINTQUEUE, username, job_id,'')
+        else:
+            log.error("SMART INSTALL (CD/DVD-ROM) is enabled in the system. Refer http://hplipopensource.com/hplip-web/index.html for more information.")
 
     # ******************************* TRIGGERING PLUGIN POP-UP FOR PLUGING SUPPORTED PRINTER'S
     plugin = mq.get('plugin', PLUGIN_NONE)
@@ -248,10 +169,12 @@ try:
           log.info("HP Device Plug-in is not found")
        else:
           log.info("HP Device Plug-in version mismatch or some files are corrupted")
-    
+
        if plugin_sts != pluginhandler.PLUGIN_INSTALLED:
            if start_systray():
                send_message( device_uri,  printer_name, EVENT_AUTO_CONFIGURE, username, job_id, "AutoConfig")
+           else:
+               log.error("HP Device plugin's are not installed. Please install plugin's using hp-plugin command.")
 
        # ******************************* RUNNING FIRMWARE DOWNLOAD TO DEVICE FOR SUPPORTED PRINTER'S
        fw_download_req = mq.get('fw-download', False)
@@ -264,20 +187,6 @@ try:
            else:
                log.warn("Failed to download firmware to %s device"%device_uri)     
 
-    # ******************************* REMOVING CUPS CREATED QUEUE, If any
-    i =0
-    while i <12:
-        time.sleep(2)
-        fax_queues_list, fax_queues_list_non_hp_conf = get_queues(serial, 'hpfax')
-        remove_queues(fax_queues_list_non_hp_conf)     # Removing Queues which are not configured by HPLIP
-
-        print_queues_list, print_queues_list_non_hp_conf = get_queues(serial, 'hp')
-        remove_queues(print_queues_list_non_hp_conf)     # Removing Queues which are not configured by HPLIP
-
-        if i == 0:
-            send_message( device_uri, printer_name, EVENT_DIAGNOSE_PRINTQUEUE, username, job_id,"")
-        i += 1
-
 except KeyboardInterrupt:
     log.error("User exit")
 
