@@ -43,14 +43,14 @@ USAGE = [(__doc__, "", "name", True),
          utils.USAGE_SPACE,
          utils.USAGE_MODE,
          ("Run in interactive mode:", "-i or --interactive (Default)", "option", False),
-         ("Run in graphical UI mode:", "-u or --gui (future use)", "option", False),
+#         ("Run in graphical UI mode:", "-u or --gui (future use)", "option", False),
          utils.USAGE_SPACE,
          utils.USAGE_OPTIONS,
          utils.USAGE_HELP,
          utils.USAGE_LOGGING1, utils.USAGE_LOGGING2, utils.USAGE_LOGGING3,
-         ("Non-interactive mode:","-n(Without asking permissions)(future use)","option",False),
-         ("Perform the task for the given device id:","-d<device id>(future use)","option",False),
-         ("Take options from the file instead of command line:","-f<file> (future use)","option",False)
+#         ("Non-interactive mode:","-n(Without asking permissions)(future use)","option",False),
+#         ("Perform the task for the given device id:","-d<device id>(future use)","option",False),
+#         ("Take options from the file instead of command line:","-f<file> (future use)","option",False)
 
         ]
 
@@ -125,7 +125,7 @@ def install_plugin(core):
         log.info("Plugin's already installed")
         return True
     else:
-        log.info("HP Properitery Plugin's are not required as no plug-in printer is present.")
+        log.info("No plug-in printers are configured.")
         return True
 
     if ok and user_input == 'y':
@@ -149,8 +149,7 @@ def deprecated_check(core):
         log.info("No Deprecated items are found")
     else:
         log.error("This distro (i.e %s  %s) is either deprecated or not yet supported."%(core.distro_name, core.distro_version))
-        ok,user_input =tui.enter_choice(log.red("The diagnosis is limited on unsupported platforms. Do you want to continue?(y=yes, n=no*):"),['y', 'n'], 'n')
-#        ok,user_input =tui.enter_choice(log.red("This tool may not diagnose all the problems. Do you want to continue?(y=yes, n=no*)"),['y', 'n'], 'n')
+        ok,user_input =tui.enter_choice(log.red("The diagnosis is limited on unsupported platforms. Do you want to continue?(y=yes*, n=no):"),['y', 'n'], 'y')
         if not ok or user_input !='y':
             clean_exit(2)
 
